import React, { useState } from "react";

import Button from "../Button";

import ax from "../../assets/images/square.svg";
import FormInput from "../FormInput";

const ProcessCard = ({ processes, title, hint, items, options }) => {
  const [openModal, setOpenModal] = useState(false);
  console.log(openModal);

  return (
    <section className="w-fit mx-auto flex flex-row bg-surface border border-blue-400 rounded">
      {/* right */}
      <div className="flex flex-1 flex-col">
        {/* top */}
        <div className="flex flex-row p-4 bg-blue-100 rounded divide-x-2 divide-blue-400 divide-x-reverse">
          {processes.map((process, index) => (
            <div
              className="flex flex-row flex-1 items-center justify-center flex-grow"
              key={index}
            >
              {process.color && (
                <div
                  className={`w-1.5 h-5 rounded ml-1.5 ${process.color}`}
                ></div>
              )}
              <p className="text-xs bg-blue-400">{process.name}</p>
              <span className="text-xs mr-2 ">{process.content}</span>
            </div>
          ))}
        </div>
        {/* middle */}
        <div className="flex flex-col p-4 my-5 mr-5">
          <h2 className="text-lg  font-bold">{title}</h2>
          <p className="text-sm text-justify leading-6 mt-3">{hint}</p>
        </div>
        {/* bottom */}
        <div className="flex flex-row item-center justify-around p-3 bg-gray-200 rounded ">
          {/* right */}
          <Button
            text={"ویرایش"}
            icon={ax}
            iconHolderClassName={""}
            iconClassName={"mr-2 w-5"}
            className="p-2 bg-primary text-white text-sm rounded"
            onClick={() => setOpenModal(true)}
          />
          {/* left */}
          <div className="flex-1 flex flex-row items-center justify-around divide-x-2 divide-blue-400 divide-x-reverse">
            {items.map((item, i) => (
              <div
                key={i}
                className="flex flex-row flex-1 items-center justify-center flex-grow"
              >
                <img src={item.icon} alt="" className="w-4 h-4 ml-1" />
                <p className="text-xs ">{item.name}</p>
                <p className="text-xs mr-1 ">{item.ans}</p>
              </div>
            ))}
          </div>
        </div>
      </div>
      {/* left */}
      <div className="flex flex-col justify-center p-2 border-r border-blue-400 gap-y-4">
        {options.map((option, j) => (
          <div key={j} className="flex flex-row items-center justify-between">
            <div className="flex flex-row items-center">
              <img src={option.icon} alt="icon" className="w-5" />
              <p className="text-xs mr-1">{option.title}</p>
            </div>
            <p className="text-xs mr-7">{option.content}</p>
          </div>
        ))}
      </div>
      {/* modal */}
      <div
        className={`cursor-pointer w-screen h-screen flex items-center justify-center bg-black fixed left-0 top-0 duration-300 transition-all
        ${openModal ? "opacity-60" : "opacity-0 pointer-events-none"}
      `}
      >
        <div
          className="w-1/2 flex flex-col  bg-white border border-gray-400 rounded-sm p-5"
          onClick={(e) => e.stopPropagation()}
        >
          <Button
            text={null}
            icon={ax}
            iconHolderClassName={""}
            iconClassName={""}
            className="p-2 bg-red-600 rounded self-end"
            onClick={() => setOpenModal(false)}
          />
          {/* <FormInput /> */}
        </div>
      </div>
    </section>
  );
};

export default ProcessCard;

ProcessCard.defaultProps = {
  title: "پروسه مختلف در این قسمت قرار می گیرد",
  hint: "یک توضیح کوتاه در این پروسه در اینجا قرار خواهد گرفت که نشان دهنده چیز های مختلف است.",

  processes: [
    {
      color: "bg-error",
      name: "فرایند اجرایی",
      content: 256,
    },
    {
      color: false,
      name: "وضعیت:",
      content: "پرداخت شده",
    },
    {
      color: "bg-info",
      name: "در حال انجام",
      content: 55,
    },
    {
      color: false,
      name: "انجام شده",
      content: 100,
    },
  ],

  items: [
    {
      icon: ax,
      name: "سوالات:",
      ans: 5,
    },
    {
      icon: ax,
      name: "چک لیست:",
      ans: "تابع دارد",
    },
    {
      icon: ax,
      name: "مکاتبات:",
      ans: "دارد",
    },
  ],

  options: [
    {
      icon: ax,
      title: "تاخیر",
      content: "5 ساعت",
    },
    {
      icon: ax,
      title: "شرایط اجرا",
      content: "2 مورد",
    },
    {
      icon: ax,
      title: "تابع شروع",
      content: "ندارد",
    },
    {
      icon: ax,
      title: "مثلث",
      content: "5 ساعت",
    },
    {
      icon: ax,
      title: "تایید خودکار",
      content: "5 ساعت",
    },
    {
      icon: ax,
      title: "تابع انجام",
      content: "ندارد",
    },
  ],
};
